#include "ofApp.h"

//--------------------------------------------------------------
void ofApp::setup(){

	mfloat = 0;
	mentholor.setProgramID( "MDEV" );
	mentholor.add(&mfloat, "/demo_float");

	//mentholor.generateUI();
	vector< string > jsons;
	jsons.push_back( "track1.json" );
	jsons.push_back( "track2.json" );
	mentholor.playerLoad( jsons );

	ofAddListener( mentholor.mentholEvent, this, &ofApp::mtlrEvent );

}

//--------------------------------------------------------------
void ofApp::update(){

	mentholor.update();
	mentholor.playerJumpTo( ofGetElapsedTimeMillis() );

	while( values.size() > 300 ) {
		values.erase( values.begin() );
	}
	values.push_back( mfloat );

}

//--------------------------------------------------------------
void ofApp::draw(){

	ofSetColor( 255,0,0 );

	float prev = 0;
	float x = 0;
	for ( vector< float >::iterator it = values.begin(); it != values.end(); ++it ) {
		if ( it == values.begin() ) {
			prev = (*it);
			continue;
		}
		float prevx = x;
		x += 3;
		ofLine(
			20 + prevx, 360 - prev * 100,
			20 + x, 360 - (*it) * 100
			);
		prev = (*it);
	}
	
	ofSetColor( 0,0,0 );
	stringstream ss;
	ss << "player head: " << mentholor.getPercent() << endl;
	ss << "player duration: " << mentholor.playerDuration() << endl;
	ofDrawBitmapString( ss.str(), 10, 25 );

}

//--------------------------------------------------------------
void ofApp::keyPressed(int key){

}

//--------------------------------------------------------------
void ofApp::keyReleased(int key){

}

//--------------------------------------------------------------
void ofApp::mouseMoved(int x, int y ){

}

//--------------------------------------------------------------
void ofApp::mouseDragged(int x, int y, int button){

}

//--------------------------------------------------------------
void ofApp::mousePressed(int x, int y, int button){

}

//--------------------------------------------------------------
void ofApp::mouseReleased(int x, int y, int button){

}

//--------------------------------------------------------------
void ofApp::windowResized(int w, int h){

}

//--------------------------------------------------------------
void ofApp::gotMessage(ofMessage msg){

}

//--------------------------------------------------------------
void ofApp::dragEvent(ofDragInfo dragInfo){ 

}

void ofApp::mtlrEvent(ofxMentholEventArgs & e) {

    stringstream ss;
    string name = e.name;

	switch ( e.event ) {

		default:
		case MTE_UNDEFINED:
			ss << "UNDEFINED EVENT TYPE" << endl;
			break;

		case MTE_TIMELINE_START:
			ss << "timeline '" << e.name << "' starts";
			break;

		case MTE_TIMELINE_STOP:
			ss << "timeline '" << e.name << "' stops";
			break;

		case MTE_TIMELINE_LOOP:
			ss << "timeline '" << e.name << "' loops";
			break;

		case MTE_NEW_VALUE:
			{
			switch ( e.type ) {
				case MTV_BANG:
					ss << e.name << " (bang) no value";
					break;
				case MTV_BOOLEAN:
					ss << e.name << " (bool) " << mentholor.asBool(e);
					break;
				case MTV_INT:
					ss << e.name << " (int) " << mentholor.asInt(e);
					break;
				case MTV_FLOAT:
					ss << e.name << " (float) " << mentholor.asFloat(e);
					break;
				case MTV_DOUBLE:
					ss << e.name << " (double) " << mentholor.asDouble(e);
					break;
				case MTV_STRING:
					ss << e.name << " (string) " << mentholor.asString(e);
					break;
				case MTV_VEC3:
					ss << e.name << " (vec3) " << mentholor.asVec3(e);
					break;
				case MTV_VEC4:
					ss << e.name << " (vec4) " << mentholor.asVec4(e);
					break;
				case MTV_COLOR:
					ss << e.name << " (color) " << mentholor.asColor(e);
					break;
				case MTV_ENUM:
					ss << e.name << " (enum) " << mentholor.asInt(e);
					break;
				default:
					ss << "?????????????????";
					break;
			}
			}
			break;
	}

}